// (C) 2023-2025 GoodData Corporation
import React, { useMemo } from "react";
import { FormattedMessage, useIntl } from "react-intl";
import { Bubble, BubbleHoverTrigger } from "@gooddata/sdk-ui-kit";
import cx from "classnames";
import { messages } from "../../../../locales.js";
const ALIGN_POINTS = [{ align: "bl tl" }];
const ARROW_OFFSETS = { "bl tl": [0, 8] };
export const AttributeFilterShowFilteredElements = ({ attributeTitle, onClick, parentFilterTitles, isFilteredByLimitingValidationItems, className, }) => {
    const intl = useIntl();
    const hasParentFilters = parentFilterTitles.length > 0;
    const tooltipLocalizationKey = hasParentFilters
        ? isFilteredByLimitingValidationItems
            ? messages.relevantValuesParentFiltersLimitsTooltip
            : messages.relevantValuesParentFiltersTooltip
        : messages.relevantValuesLimitsTooltip;
    const parentFiltersTooltipText = useMemo(() => {
        return parentFilterTitles ? parentFilterTitles.join(", ") : "";
    }, [parentFilterTitles]);
    const handleClick = (e) => {
        e.preventDefault();
        onClick();
    };
    return (React.createElement("div", { className: cx("gd-attribute-filter-status-show-all s-attribute-filter-status-show-all", className) },
        React.createElement(BubbleHoverTrigger, { showDelay: 0, hideDelay: 0 },
            React.createElement("div", { className: "gd-relevant-values-text" },
                React.createElement(FormattedMessage, { id: "attributesDropdown.relevantValues", values: { nbsp: React.createElement(React.Fragment, null, "\u00A0") } })),
            React.createElement(Bubble, { className: `bubble-primary gd-attribute-filter-dropdown-bubble__next s-attribute-filter-dropdown-bubble`, alignPoints: ALIGN_POINTS, arrowOffsets: ARROW_OFFSETS }, intl.formatMessage(tooltipLocalizationKey, {
                child: attributeTitle,
                parents: parentFiltersTooltipText,
                strong: (chunks) => React.createElement("strong", null, chunks),
            }))),
        React.createElement("button", { className: "gd-action-show-all s-action-show-all", onClick: handleClick },
            React.createElement(FormattedMessage, { id: "attributesDropdown.showAll" }))));
};
//# sourceMappingURL=AttributeFilterShowFilteredElements.js.map