// (C) 2022-2025 GoodData Corporation
import React, { useContext } from "react";
import { useAttributeFilterController } from "../hooks/useAttributeFilterController.js";
export const AttributeFilterContext = React.createContext(null);
AttributeFilterContext.displayName = "AttributeFilterContext";
/**
 * Context providing AttributeFilter state and callbacks wrapped as {@link AttributeFilterController}.
 * @beta
 */
export const useAttributeFilterContext = () => useContext(AttributeFilterContext);
/**
 * @internal
 */
export const AttributeFilterContextProvider = (props) => {
    const { children, fullscreenOnMobile, title: titleInput, selectionMode, selectFirst, disabled, customIcon, enableDuplicatedLabelValuesInAttributeFilter = true, withoutApply, workingFilter, overlayPositionType, } = props;
    const controller = useAttributeFilterController(props);
    const title = titleInput ?? controller?.attribute?.title ?? "";
    return (React.createElement(AttributeFilterContext.Provider, { value: {
            ...controller,
            fullscreenOnMobile,
            title,
            selectionMode,
            selectFirst,
            disabled,
            customIcon,
            enableDuplicatedLabelValuesInAttributeFilter,
            withoutApply,
            workingFilter,
            overlayPositionType,
        } }, children));
};
//# sourceMappingURL=AttributeFilterContext.js.map