// (C) 2021-2022 GoodData Corporation
import { useMemo } from "react";
import { useResolveValueWithPlaceholders } from "@gooddata/sdk-ui";
import { filterIsEmpty } from "@gooddata/sdk-model";
import isFunction from "lodash/isFunction.js";
/**
 * @internal
 */
export const useResolveParentFiltersInput = (parentFilters, overAttribute, supportsSettingConnectingAttributes) => {
    const resolvedParentFilters = useResolveValueWithPlaceholders(parentFilters);
    return useMemo(() => {
        if (!supportsSettingConnectingAttributes) {
            return getParentFiltersWithoutOverAttribute(resolvedParentFilters);
        }
        return getParentFiltersWithOverAttribute(resolvedParentFilters, overAttribute);
    }, [supportsSettingConnectingAttributes, resolvedParentFilters, overAttribute]);
};
const getParentFiltersWithoutOverAttribute = (parentFilters) => {
    if (!parentFilters) {
        return [];
    }
    return parentFilters.map((attributeFilter) => ({ attributeFilter, overAttribute: null }));
};
const getParentFiltersWithOverAttribute = (parentFilters, overAttribute) => {
    if (!parentFilters || !overAttribute) {
        return [];
    }
    const overAttributeGetter = isFunction(overAttribute) ? overAttribute : () => overAttribute;
    return parentFilters
        .map((attributeFilter, index) => {
        return {
            attributeFilter,
            overAttribute: overAttributeGetter(attributeFilter, index),
        };
    })
        .filter((item) => {
        return !filterIsEmpty(item.attributeFilter);
    });
};
//# sourceMappingURL=useResolveParentFiltersInput.js.map