import { IElementsQueryAttributeFilter } from "@gooddata/sdk-backend-spi";
import { IAttributeElement, IAttributeMetadataObject, IAttributeFilter, IMeasure, IRelativeDateFilter, SortDirection, ObjRef, IAbsoluteDateFilter } from "@gooddata/sdk-model";
import { GoodDataSdkError } from "@gooddata/sdk-ui";
import { AsyncOperationStatus, CallbackRegistration, Correlation, ILoadElementsOptions, InvertableAttributeElementSelection, OnInitStartCallbackPayload, OnInitSuccessCallbackPayload, OnInitErrorCallbackPayload, OnInitCancelCallbackPayload, OnLoadAttributeStartCallbackPayload, OnLoadAttributeSuccessCallbackPayload, OnLoadAttributeErrorCallbackPayload, OnLoadAttributeCancelCallbackPayload, OnLoadInitialElementsPageStartCallbackPayload, OnLoadInitialElementsPageSuccessCallbackPayload, OnLoadInitialElementsPageErrorCallbackPayload, OnLoadInitialElementsPageCancelCallbackPayload, OnLoadNextElementsPageStartCallbackPayload, OnLoadNextElementsPageSuccessCallbackPayload, OnLoadNextElementsPageErrorCallbackPayload, OnLoadNextElementsPageCancelCallbackPayload, OnLoadCustomElementsStartCallbackPayload, OnLoadCustomElementsSuccessCallbackPayload, OnLoadCustomElementsErrorCallbackPayload, OnLoadCustomElementsCancelCallbackPayload, OnSelectionChangedCallbackPayload, OnSelectionCommittedCallbackPayload, OnInitTotalCountStartCallbackPayload, OnInitTotalCountCancelCallbackPayload, OnInitTotalCountErrorCallbackPayload, OnInitTotalCountSuccessCallbackPayload, OnLoadIrrelevantElementsStartCallbackPayload, OnLoadIrrelevantElementsSuccessCallbackPayload, OnLoadIrrelevantElementsErrorCallbackPayload, OnLoadIrrelevantElementsCancelCallbackPayload } from "../types/index.js";
import { AttributeFilterHandlerConfig } from "./types.js";
/**
 * @internal
 */
export declare class AttributeFilterReduxBridge {
    private redux;
    private config;
    private callbacks;
    constructor(config: AttributeFilterHandlerConfig);
    private initializeBridge;
    init: (correlation: Correlation) => void;
    getInitStatus: () => AsyncOperationStatus;
    getInitError: () => GoodDataSdkError | undefined;
    onInitStart: CallbackRegistration<OnInitStartCallbackPayload>;
    onInitSuccess: CallbackRegistration<OnInitSuccessCallbackPayload>;
    onInitError: CallbackRegistration<OnInitErrorCallbackPayload>;
    onInitCancel: CallbackRegistration<OnInitCancelCallbackPayload>;
    initTotalCount: (correlation: Correlation) => void;
    getInitTotalCountStatus: () => AsyncOperationStatus;
    getInitTotalCountError: () => GoodDataSdkError | undefined;
    onInitTotalCountStart: CallbackRegistration<OnInitTotalCountStartCallbackPayload>;
    onInitTotalCountSuccess: CallbackRegistration<OnInitTotalCountSuccessCallbackPayload>;
    onInitTotalCountError: CallbackRegistration<OnInitTotalCountErrorCallbackPayload>;
    onInitTotalCountCancel: CallbackRegistration<OnInitTotalCountCancelCallbackPayload>;
    loadAttribute: (correlation: Correlation) => void;
    cancelAttributeLoad: () => void;
    getAttribute: () => IAttributeMetadataObject | undefined;
    getAttributeStatus: () => AsyncOperationStatus;
    getAttributeError: () => GoodDataSdkError | undefined;
    onLoadAttributeStart: CallbackRegistration<OnLoadAttributeStartCallbackPayload>;
    onLoadAttributeSuccess: CallbackRegistration<OnLoadAttributeSuccessCallbackPayload>;
    onLoadAttributeError: CallbackRegistration<OnLoadAttributeErrorCallbackPayload>;
    onLoadAttributeCancel: CallbackRegistration<OnLoadAttributeCancelCallbackPayload>;
    loadInitialElementsPage: (correlation: Correlation) => void;
    cancelInitialElementsPageLoad: () => void;
    getInitialElementsPageStatus: () => AsyncOperationStatus;
    getInitialElementsPageError: () => GoodDataSdkError | undefined;
    onLoadInitialElementsPageStart: CallbackRegistration<OnLoadInitialElementsPageStartCallbackPayload>;
    onLoadInitialElementsPageSuccess: CallbackRegistration<OnLoadInitialElementsPageSuccessCallbackPayload>;
    onLoadInitialElementsPageError: CallbackRegistration<OnLoadInitialElementsPageErrorCallbackPayload>;
    onLoadInitialElementsPageCancel: CallbackRegistration<OnLoadInitialElementsPageCancelCallbackPayload>;
    loadNextElementsPage: (correlation: Correlation) => void;
    cancelNextElementsPageLoad(): void;
    getNextElementsPageStatus: () => AsyncOperationStatus;
    getNextElementsPageError: () => GoodDataSdkError | undefined;
    onLoadNextElementsPageStart: CallbackRegistration<OnLoadNextElementsPageStartCallbackPayload>;
    onLoadNextElementsPageSuccess: CallbackRegistration<OnLoadNextElementsPageSuccessCallbackPayload>;
    onLoadNextElementsPageError: CallbackRegistration<OnLoadNextElementsPageErrorCallbackPayload>;
    onLoadNextElementsPageCancel: CallbackRegistration<OnLoadNextElementsPageCancelCallbackPayload>;
    loadCustomElements: (options: ILoadElementsOptions, correlation: Correlation) => void;
    cancelCustomElementsLoad(correlation: Correlation): void;
    onLoadCustomElementsStart: CallbackRegistration<OnLoadCustomElementsStartCallbackPayload>;
    onLoadCustomElementsSuccess: CallbackRegistration<OnLoadCustomElementsSuccessCallbackPayload>;
    onLoadCustomElementsError: CallbackRegistration<OnLoadCustomElementsErrorCallbackPayload>;
    onLoadCustomElementsCancel: CallbackRegistration<OnLoadCustomElementsCancelCallbackPayload>;
    loadIrrelevantElements: (correlation?: Correlation) => void;
    cancelIrrelevantElementsLoad(correlation?: Correlation): void;
    onLoadIrrelevantElementsStart: CallbackRegistration<OnLoadIrrelevantElementsStartCallbackPayload>;
    onLoadIrrelevantElementsSuccess: CallbackRegistration<OnLoadIrrelevantElementsSuccessCallbackPayload>;
    onLoadIrrelevantElementsError: CallbackRegistration<OnLoadIrrelevantElementsErrorCallbackPayload>;
    onLoadIrrelevantElementsCancel: CallbackRegistration<OnLoadIrrelevantElementsCancelCallbackPayload>;
    setDisplayAsLabel: (displayAsLabel: ObjRef, correlation?: Correlation) => void;
    getDisplayAsLabel: () => ObjRef | undefined;
    setDisplayForm: (displayForm: ObjRef, correlation?: Correlation) => void;
    getOffset: () => number;
    setSearch: (search: string) => void;
    getSearch: () => string;
    setLimit: (limit: number) => void;
    getLimit: () => number;
    setOrder: (order: SortDirection) => void;
    getOrder: () => SortDirection;
    setLimitingMeasures: (filters: IMeasure[]) => void;
    getLimitingMeasures: () => IMeasure[];
    setLimitingValidationItems: (validateBy: ObjRef[]) => void;
    getLimitingValidationItems: () => ObjRef[];
    setLimitingAttributeFilters: (filters: IElementsQueryAttributeFilter[]) => void;
    getLimitingAttributeFilters: () => IElementsQueryAttributeFilter[];
    setLimitingDateFilters: (filters: IRelativeDateFilter[] | IAbsoluteDateFilter[]) => void;
    getLimitingDateFilters: () => IRelativeDateFilter[] | IAbsoluteDateFilter[];
    getAllElements: () => IAttributeElement[];
    getElementsByKey: (keys: string[]) => IAttributeElement[];
    getTotalCount: () => number;
    getTotalCountWithCurrentSettings: () => number;
    getLimitingAttributeFiltersAttributes: () => IAttributeMetadataObject[];
    changeMultiSelection: ({ keys, isInverted, irrelevantKeys, }: InvertableAttributeElementSelection) => void;
    revertMultiSelection: () => void;
    commitMultiSelection: () => void;
    invertMultiSelection: () => void;
    clearMultiSelection: () => void;
    getWorkingMultiSelection: () => InvertableAttributeElementSelection;
    getCommittedMultiSelection: () => InvertableAttributeElementSelection;
    changeSingleSelection: (selection: string | undefined) => void;
    revertSingleSelection: () => void;
    commitSingleSelection: () => void;
    getWorkingSingleSelection: () => string | undefined;
    getCommittedSingleSelection: () => string | undefined;
    onMultiSelectionChanged: CallbackRegistration<OnSelectionChangedCallbackPayload<InvertableAttributeElementSelection>>;
    onMultiSelectionCommitted: CallbackRegistration<OnSelectionCommittedCallbackPayload<InvertableAttributeElementSelection>>;
    onSingleSelectionChanged: CallbackRegistration<OnSelectionChangedCallbackPayload<string | undefined>>;
    onSingleSelectionCommitted: CallbackRegistration<OnSelectionCommittedCallbackPayload<string | undefined>>;
    getIsWorkingSelectionEmpty: () => boolean;
    getIsWorkingSelectionChanged: () => boolean;
    getFilter: () => IAttributeFilter;
    getFilterToDisplay: () => IAttributeFilter;
    getOriginalFilter: () => IAttributeFilter;
    onUpdate: CallbackRegistration<void>;
    isLoadElementsOptionsChanged: () => boolean;
}
//# sourceMappingURL=bridge.d.ts.map