// (C) 2022-2024 GoodData Corporation
import { invariant } from "ts-invariant";
import compact from "lodash/compact.js";
import { actions, createAttributeFilterHandlerStore, selectAttribute, selectElements, selectElementsTotalCount, selectElementsTotalCountWithCurrentSettings, selectAttributeFilter, selectSearch, selectWorkingSelection, selectCommittedSelection, selectElementsCache, getElementsByKeys, selectAttributeStatus, selectAttributeError, selectInitStatus, selectInitError, selectLoadInitialElementsPageStatus, selectLoadInitialElementsPageError, selectLoadNextElementsPageStatus, selectLoadNextElementsPageError, selectLimitingMeasures, selectLimitingAttributeFilters, selectLimitingDateFilters, selectLimit, selectOrder, selectInvertableCommittedSelection, selectInvertableWorkingSelection, selectIsWorkingSelectionChanged, selectIsWorkingSelectionEmpty, selectOffset, selectIsLoadElementsOptionsChanged, selectLimitingAttributeFiltersAttributes, selectInitTotalCountStatus, selectInitTotalCountError, selectLimitingValidationItems, selectAttributeFilterToDisplay, selectOriginalFilter, selectAttributeFilterDisplayAsLabel, } from "./redux/index.js";
import { newAttributeFilterCallbacks } from "./callbacks.js";
/**
 * @internal
 */
export class AttributeFilterReduxBridge {
    redux;
    config;
    callbacks;
    constructor(config) {
        this.config = config;
        this.initializeBridge();
    }
    initializeBridge = () => {
        this.callbacks = newAttributeFilterCallbacks();
        this.redux = createAttributeFilterHandlerStore({
            ...this.config,
            eventListener: (action, select) => {
                this.callbacks.eventListener(action, select);
            },
        });
    };
    //
    // Init
    //
    init = (correlation) => {
        this.redux.dispatch(actions.init({
            correlation,
        }));
    };
    getInitStatus = () => {
        return this.redux.select(selectInitStatus);
    };
    getInitError = () => {
        return this.redux.select(selectInitError);
    };
    onInitStart = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.initStart);
    };
    onInitSuccess = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.initSuccess);
    };
    onInitError = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.initError);
    };
    onInitCancel = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.initCancel);
    };
    // total count init
    initTotalCount = (correlation) => {
        this.redux.dispatch(actions.initTotalCount({
            correlation,
        }));
    };
    getInitTotalCountStatus = () => {
        return this.redux.select(selectInitTotalCountStatus);
    };
    getInitTotalCountError = () => {
        return this.redux.select(selectInitTotalCountError);
    };
    onInitTotalCountStart = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.initTotalCountStart);
    };
    onInitTotalCountSuccess = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.initTotalCountSuccess);
    };
    onInitTotalCountError = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.initTotalCountError);
    };
    onInitTotalCountCancel = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.initTotalCountCancel);
    };
    //
    // Attribute
    //
    loadAttribute = (correlation) => {
        this.redux.dispatch(actions.loadAttributeRequest({ correlation: correlation }));
    };
    cancelAttributeLoad = () => {
        this.redux.dispatch(actions.loadAttributeCancelRequest());
    };
    getAttribute = () => {
        return this.redux.select(selectAttribute);
    };
    getAttributeStatus = () => {
        return this.redux.select(selectAttributeStatus);
    };
    getAttributeError = () => {
        return this.redux.select(selectAttributeError);
    };
    onLoadAttributeStart = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadAttributeStart);
    };
    onLoadAttributeSuccess = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadAttributeSuccess);
    };
    onLoadAttributeError = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadAttributeError);
    };
    onLoadAttributeCancel = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadAttributeCancel);
    };
    //
    // Initial elements page
    //
    loadInitialElementsPage = (correlation) => {
        this.redux.dispatch(actions.loadInitialElementsPageRequest({ correlation: correlation }));
    };
    cancelInitialElementsPageLoad = () => {
        this.redux.dispatch(actions.loadInitialElementsPageCancelRequest());
    };
    getInitialElementsPageStatus = () => {
        return this.redux.select(selectLoadInitialElementsPageStatus);
    };
    getInitialElementsPageError = () => {
        return this.redux.select(selectLoadInitialElementsPageError);
    };
    onLoadInitialElementsPageStart = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadInitialElementsPageStart);
    };
    onLoadInitialElementsPageSuccess = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadInitialElementsPageSuccess);
    };
    onLoadInitialElementsPageError = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadInitialElementsPageError);
    };
    onLoadInitialElementsPageCancel = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadInitialElementsPageCancel);
    };
    //
    // Next elements page
    //
    loadNextElementsPage = (correlation) => {
        this.redux.dispatch(actions.loadNextElementsPageRequest({ correlation: correlation }));
    };
    cancelNextElementsPageLoad() {
        this.redux.dispatch(actions.loadNextElementsPageCancelRequest());
    }
    getNextElementsPageStatus = () => {
        return this.redux.select(selectLoadNextElementsPageStatus);
    };
    getNextElementsPageError = () => {
        return this.redux.select(selectLoadNextElementsPageError);
    };
    onLoadNextElementsPageStart = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadNextElementsPageStart);
    };
    onLoadNextElementsPageSuccess = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadNextElementsPageSuccess);
    };
    onLoadNextElementsPageError = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadNextElementsPageError);
    };
    onLoadNextElementsPageCancel = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadNextElementsPageCancel);
    };
    //
    // Custom elements
    //
    loadCustomElements = (options, correlation) => {
        this.redux.dispatch(actions.loadCustomElementsRequest({ options, correlation: correlation }));
    };
    cancelCustomElementsLoad(correlation) {
        this.redux.dispatch(actions.loadCustomElementsCancelRequest({ correlation: correlation }));
    }
    onLoadCustomElementsStart = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadCustomElementsStart);
    };
    onLoadCustomElementsSuccess = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadCustomElementsSuccess);
    };
    onLoadCustomElementsError = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadCustomElementsError);
    };
    onLoadCustomElementsCancel = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadCustomElementsCancel);
    };
    //
    // Irrelevant elements
    //
    loadIrrelevantElements = (correlation) => {
        this.redux.dispatch(actions.loadIrrelevantElementsRequest({ correlation: correlation }));
    };
    cancelIrrelevantElementsLoad(correlation) {
        this.redux.dispatch(actions.loadIrrelevantElementsCancelRequest({ correlation: correlation }));
    }
    onLoadIrrelevantElementsStart = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadIrrelevantElementsStart);
    };
    onLoadIrrelevantElementsSuccess = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadIrrelevantElementsSuccess);
    };
    onLoadIrrelevantElementsError = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadIrrelevantElementsError);
    };
    onLoadIrrelevantElementsCancel = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.loadIrrelevantElementsCancel);
    };
    //
    // Elements options
    //
    setDisplayAsLabel = (displayAsLabel, correlation) => {
        this.redux.dispatch(actions.setDisplayAsLabel({ displayAsLabel, correlation }));
    };
    getDisplayAsLabel = () => {
        return this.redux.select(selectAttributeFilterDisplayAsLabel);
    };
    setDisplayForm = (displayForm, correlation) => {
        this.redux.dispatch(actions.setDisplayFormRef({ displayForm, correlation }));
    };
    getOffset = () => {
        return this.redux.select(selectOffset);
    };
    setSearch = (search) => {
        this.redux.dispatch(actions.setSearch({ search }));
    };
    getSearch = () => {
        return this.redux.select(selectSearch);
    };
    setLimit = (limit) => {
        this.redux.dispatch(actions.setLimit({ limit }));
    };
    getLimit = () => {
        return this.redux.select(selectLimit);
    };
    setOrder = (order) => {
        this.redux.dispatch(actions.setOrder({ order }));
    };
    getOrder = () => {
        return this.redux.select(selectOrder);
    };
    setLimitingMeasures = (filters) => {
        this.redux.dispatch(actions.setLimitingMeasures({ filters }));
    };
    getLimitingMeasures = () => {
        return this.redux.select(selectLimitingMeasures);
    };
    setLimitingValidationItems = (validateBy) => {
        this.redux.dispatch(actions.setLimitingValidationItems({ validateBy }));
    };
    getLimitingValidationItems = () => {
        return this.redux.select(selectLimitingValidationItems);
    };
    setLimitingAttributeFilters = (filters) => {
        this.redux.dispatch(actions.setLimitingAttributeFilters({ filters }));
    };
    getLimitingAttributeFilters = () => {
        return this.redux.select(selectLimitingAttributeFilters);
    };
    setLimitingDateFilters = (filters) => {
        this.redux.dispatch(actions.setLimitingDateFilters({ filters }));
    };
    getLimitingDateFilters = () => {
        return this.redux.select(selectLimitingDateFilters);
    };
    //
    // Elements
    //
    getAllElements = () => {
        return this.redux.select(selectElements);
    };
    getElementsByKey = (keys) => {
        const elementsCache = this.redux.select(selectElementsCache);
        return getElementsByKeys(keys, elementsCache);
    };
    getTotalCount = () => {
        return this.redux.select(selectElementsTotalCount);
    };
    getTotalCountWithCurrentSettings = () => {
        return this.redux.select(selectElementsTotalCountWithCurrentSettings);
    };
    getLimitingAttributeFiltersAttributes = () => {
        return this.redux.select(selectLimitingAttributeFiltersAttributes);
    };
    //
    // Multi select
    //
    changeMultiSelection = ({ keys, isInverted, irrelevantKeys, }) => {
        this.redux.dispatch(actions.changeSelection({
            selection: keys,
            isInverted,
            irrelevantSelection: irrelevantKeys,
        }));
    };
    revertMultiSelection = () => {
        this.redux.dispatch(actions.revertSelection());
    };
    commitMultiSelection = () => {
        this.redux.dispatch(actions.commitSelection());
    };
    invertMultiSelection = () => {
        this.redux.dispatch(actions.invertSelection());
    };
    clearMultiSelection = () => {
        this.redux.dispatch(actions.clearSelection());
    };
    getWorkingMultiSelection = () => {
        return this.redux.select(selectInvertableWorkingSelection);
    };
    getCommittedMultiSelection = () => {
        return this.redux.select(selectInvertableCommittedSelection);
    };
    // Single select
    changeSingleSelection = (selection) => {
        this.redux.dispatch(actions.changeSelection({
            isInverted: false,
            selection: compact([selection]),
        }));
    };
    revertSingleSelection = () => {
        this.redux.dispatch(actions.revertSelection());
    };
    commitSingleSelection = () => {
        this.redux.dispatch(actions.commitSelection());
    };
    getWorkingSingleSelection = () => {
        const [element, ...maybeMoreElements] = this.redux.select(selectWorkingSelection);
        invariant(!maybeMoreElements.length, "Trying to invoke single select method, but multiple elements are selected.");
        return element;
    };
    getCommittedSingleSelection = () => {
        const [element, ...maybeMoreElements] = this.redux.select(selectCommittedSelection);
        invariant(!maybeMoreElements.length, "Trying to invoke single select method, but multiple elements are selected.");
        return element;
    };
    onMultiSelectionChanged = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.selectionChanged);
    };
    onMultiSelectionCommitted = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.selectionCommitted);
    };
    onSingleSelectionChanged = (cb) => {
        return this.callbacks.registerCallback(({ selection }) => cb({ selection: selection.keys[0] }), this.callbacks.registrations.selectionChanged);
    };
    onSingleSelectionCommitted = (cb) => {
        return this.callbacks.registerCallback(({ selection }) => cb({ selection: selection.keys[0] }), this.callbacks.registrations.selectionCommitted);
    };
    //
    // Selection
    //
    getIsWorkingSelectionEmpty = () => {
        return this.redux.select(selectIsWorkingSelectionEmpty);
    };
    getIsWorkingSelectionChanged = () => {
        return this.redux.select(selectIsWorkingSelectionChanged);
    };
    //
    // Filter
    //
    getFilter = () => {
        return this.redux.select(selectAttributeFilter);
    };
    getFilterToDisplay = () => {
        return this.redux.select(selectAttributeFilterToDisplay);
    };
    getOriginalFilter = () => {
        return this.redux.select(selectOriginalFilter);
    };
    onUpdate = (cb) => {
        return this.callbacks.registerCallback(cb, this.callbacks.registrations.update);
    };
    isLoadElementsOptionsChanged = () => {
        return this.redux.select(selectIsLoadElementsOptionsChanged);
    };
}
//# sourceMappingURL=bridge.js.map