// (C) 2022-2025 GoodData Corporation
import { v4 as uuid } from "uuid";
import { invariant } from "ts-invariant";
import { AttributeFilterReduxBridge } from "./bridge.js";
/**
 * @internal
 */
export class AttributeFilterLoader {
    bridge;
    config;
    constructor(config) {
        this.config = config;
        this.bridge = new AttributeFilterReduxBridge(config);
    }
    validateStaticElementsLoad = () => {
        invariant(!(this.config.staticElements?.length && this.getLimitingAttributeFilters()?.length), "Using limitingAttributeFilters is not supported when using static attribute elements");
        invariant(!(this.config.staticElements?.length && this.getLimitingDateFilters()?.length), "Using limitingDateFilters is not supported when using static attribute elements");
        invariant(!(this.config.staticElements?.length && this.getLimitingMeasures()?.length), "Using limitingMeasures is not supported when using static attribute elements");
        invariant(!(this.config.staticElements?.length && this.getLimitingValidationItems()?.length), "Using limitingValidationItems is not supported when using static attribute elements");
    };
    //
    // Init
    //
    init = (correlation = uuid()) => {
        this.validateStaticElementsLoad();
        this.bridge.init(correlation);
    };
    onInitStart = (cb) => {
        return this.bridge.onInitStart(cb);
    };
    onInitSuccess = (cb) => {
        return this.bridge.onInitSuccess(cb);
    };
    onInitError = (cb) => {
        return this.bridge.onInitError(cb);
    };
    onInitCancel = (cb) => {
        return this.bridge.onInitCancel(cb);
    };
    getInitStatus = () => {
        return this.bridge.getInitStatus();
    };
    getInitError = () => {
        return this.bridge.getInitError();
    };
    //
    // Init total count
    //
    initTotalCount = (correlation = uuid()) => {
        this.bridge.initTotalCount(correlation);
    };
    getInitTotalCountStatus = () => {
        return this.bridge.getInitTotalCountStatus();
    };
    getInitTotalCountError = () => {
        return this.bridge.getInitTotalCountError();
    };
    onInitTotalCountStart = (cb) => {
        return this.bridge.onInitTotalCountStart(cb);
    };
    onInitTotalCountSuccess = (cb) => {
        return this.bridge.onInitTotalCountSuccess(cb);
    };
    onInitTotalCountError = (cb) => {
        return this.bridge.onInitTotalCountError(cb);
    };
    onInitTotalCountCancel = (cb) => {
        return this.bridge.onInitTotalCountCancel(cb);
    };
    //
    // Attribute
    //
    loadAttribute = (correlation = uuid()) => {
        this.bridge.loadAttribute(correlation);
    };
    cancelAttributeLoad = () => {
        this.bridge.cancelAttributeLoad();
    };
    getAttribute = () => {
        return this.bridge.getAttribute();
    };
    getAttributeError = () => {
        return this.bridge.getAttributeError();
    };
    getAttributeStatus = () => {
        return this.bridge.getAttributeStatus();
    };
    onLoadAttributeStart = (cb) => {
        return this.bridge.onLoadAttributeStart(cb);
    };
    onLoadAttributeSuccess = (cb) => {
        return this.bridge.onLoadAttributeSuccess(cb);
    };
    onLoadAttributeError = (cb) => {
        return this.bridge.onLoadAttributeError(cb);
    };
    onLoadAttributeCancel = (cb) => {
        return this.bridge.onLoadAttributeCancel(cb);
    };
    // Initial elements page
    loadInitialElementsPage = (correlation = uuid()) => {
        const initStatus = this.bridge.getInitStatus();
        if (initStatus === "error") {
            // do not try to fetch any elements when filter is in error state as we would end up with
            // "blank page" error in production. This can happen when user sets limiting metric that
            // is not LDM compatible (cannot be sliced) with the attribute filter's attribute.
            return;
        }
        invariant(initStatus === "success", "Cannot call loadInitialElementsPage() before successful initialization.");
        this.validateStaticElementsLoad();
        this.bridge.loadInitialElementsPage(correlation);
    };
    cancelInitialElementsPageLoad() {
        this.bridge.cancelInitialElementsPageLoad();
    }
    getInitialElementsPageStatus = () => {
        return this.bridge.getInitialElementsPageStatus();
    };
    getInitialElementsPageError = () => {
        return this.bridge.getInitialElementsPageError();
    };
    onLoadInitialElementsPageStart = (cb) => {
        return this.bridge.onLoadInitialElementsPageStart(cb);
    };
    onLoadInitialElementsPageSuccess = (cb) => {
        return this.bridge.onLoadInitialElementsPageSuccess(cb);
    };
    onLoadInitialElementsPageError = (cb) => {
        return this.bridge.onLoadInitialElementsPageError(cb);
    };
    onLoadInitialElementsPageCancel = (cb) => {
        return this.bridge.onLoadInitialElementsPageCancel(cb);
    };
    //
    // Next elements page
    //
    loadNextElementsPage = (correlation = uuid()) => {
        invariant(this.bridge.getInitStatus() === "success", "Cannot call loadNextElementsPage() before successful initialization.");
        invariant(this.bridge.getInitialElementsPageStatus() === "success", "Cannot call loadNextElementsPage() before loadInitialElementsPage() completes.");
        invariant(!this.bridge.isLoadElementsOptionsChanged(), "Cannot call loadNextElementsPage() when load element options were changed. When options are changed, you should call loadInitialElementsPage() first.");
        this.bridge.loadNextElementsPage(correlation);
    };
    cancelNextElementsPageLoad() {
        this.bridge.cancelNextElementsPageLoad();
    }
    getNextElementsPageStatus = () => {
        return this.bridge.getNextElementsPageStatus();
    };
    getNextElementsPageError = () => {
        return this.bridge.getNextElementsPageError();
    };
    onLoadNextElementsPageStart = (cb) => {
        return this.bridge.onLoadNextElementsPageStart(cb);
    };
    onLoadNextElementsPageSuccess = (cb) => {
        return this.bridge.onLoadNextElementsPageSuccess(cb);
    };
    onLoadNextElementsPageError = (cb) => {
        return this.bridge.onLoadNextElementsPageError(cb);
    };
    onLoadNextElementsPageCancel = (cb) => {
        return this.bridge.onLoadNextElementsPageCancel(cb);
    };
    //
    // Custom elements
    //
    loadCustomElements = (options, correlation) => {
        this.bridge.loadCustomElements(options, correlation);
    };
    cancelCustomElementsLoad(correlation) {
        this.bridge.cancelCustomElementsLoad(correlation);
    }
    onLoadCustomElementsStart = (cb) => {
        return this.bridge.onLoadCustomElementsStart(cb);
    };
    onLoadCustomElementsSuccess = (cb) => {
        return this.bridge.onLoadCustomElementsSuccess(cb);
    };
    onLoadCustomElementsError = (cb) => {
        return this.bridge.onLoadCustomElementsError(cb);
    };
    onLoadCustomElementsCancel = (cb) => {
        return this.bridge.onLoadCustomElementsCancel(cb);
    };
    //
    // Irrelevant elements
    //
    loadIrrelevantElements = (correlation) => {
        this.bridge.loadIrrelevantElements(correlation);
    };
    cancelIrrelevantElementsLoad(correlation) {
        this.bridge.cancelIrrelevantElementsLoad(correlation);
    }
    onLoadIrrelevantElementsStart = (cb) => {
        return this.bridge.onLoadIrrelevantElementsStart(cb);
    };
    onLoadIrrelevantElementsSuccess = (cb) => {
        return this.bridge.onLoadIrrelevantElementsSuccess(cb);
    };
    onLoadIrrelevantElementsError = (cb) => {
        return this.bridge.onLoadIrrelevantElementsError(cb);
    };
    onLoadIrrelevantElementsCancel = (cb) => {
        return this.bridge.onLoadIrrelevantElementsCancel(cb);
    };
    // Elements options
    setDisplayAsLabel = (displayAsLabel) => {
        this.bridge.setDisplayAsLabel(displayAsLabel);
    };
    getDisplayAsLabel = () => {
        return this.bridge.getDisplayAsLabel();
    };
    setDisplayForm = (label) => {
        this.bridge.setDisplayForm(label);
    };
    getOffset = () => {
        return this.bridge.getOffset();
    };
    setSearch = (search) => {
        this.bridge.setSearch(search);
    };
    getSearch = () => {
        return this.bridge.getSearch();
    };
    setLimit = (limit) => {
        this.bridge.setLimit(limit);
    };
    getLimit = () => {
        return this.bridge.getLimit();
    };
    setOrder = (order) => {
        this.bridge.setOrder(order);
    };
    getOrder = () => {
        return this.bridge.getOrder();
    };
    setLimitingMeasures = (measures) => {
        this.bridge.setLimitingMeasures(measures);
    };
    getLimitingMeasures = () => {
        return this.bridge.getLimitingMeasures();
    };
    setLimitingValidationItems = (validateBy) => {
        this.bridge.setLimitingValidationItems(validateBy);
    };
    getLimitingValidationItems = () => {
        return this.bridge.getLimitingValidationItems();
    };
    setLimitingAttributeFilters = (filters) => {
        this.bridge.setLimitingAttributeFilters(filters);
    };
    getLimitingAttributeFilters = () => {
        return this.bridge.getLimitingAttributeFilters();
    };
    setLimitingDateFilters = (filters) => {
        this.bridge.setLimitingDateFilters(filters);
    };
    getLimitingDateFilters = () => {
        return this.bridge.getLimitingDateFilters();
    };
    getAllElements = () => {
        return this.bridge.getAllElements();
    };
    getElementsByKey = (keys) => {
        return this.bridge.getElementsByKey(keys);
    };
    getTotalElementsCount = () => {
        return this.bridge.getTotalCount();
    };
    getTotalElementsCountWithCurrentSettings = () => {
        return this.bridge.getTotalCountWithCurrentSettings();
    };
    getLimitingAttributeFiltersAttributes = () => {
        return this.bridge.getLimitingAttributeFiltersAttributes();
    };
    getFilter = () => {
        return this.bridge.getFilter();
    };
    getFilterToDisplay = () => {
        return this.bridge.getFilterToDisplay();
    };
    getOriginalFilter = () => {
        return this.bridge.getOriginalFilter();
    };
    onUpdate = (cb) => {
        return this.bridge.onUpdate(cb);
    };
}
//# sourceMappingURL=loader.js.map