import omit from "lodash/omit.js";
import { call, select } from "redux-saga/effects";
import { selectAttributeFilterDisplayAsLabel, selectAttributeFilterDisplayForm, selectHiddenElementsAsAttributeElements, } from "../filter/filterSelectors.js";
import { selectAttribute } from "../loadAttribute/loadAttributeSelectors.js";
import { getAttributeFilterContext } from "../common/sagas.js";
import { selectStaticElements } from "./elementsSelectors.js";
import { loadElements } from "./loadElements.js";
/**
 * @internal
 */
export function* elementsSaga(options, cacheId) {
    const context = yield call(getAttributeFilterContext);
    const hiddenElements = yield select(selectHiddenElementsAsAttributeElements);
    const attribute = yield select(selectAttribute);
    const attributeFilterDisplayFormRef = yield select(selectAttributeFilterDisplayForm);
    const attributeFilterDisplayAsLabelRef = yield select(selectAttributeFilterDisplayAsLabel);
    const staticElements = yield select(selectStaticElements);
    const { enableDuplicatedLabelValuesInAttributeFilter } = context;
    const filterByPrimaryLabelProp = enableDuplicatedLabelValuesInAttributeFilter && attributeFilterDisplayAsLabelRef && !options.search // when searching by string, we need to apply it to the displayAsLabel directly not primary label
        ? { filterByPrimaryLabel: true }
        : {};
    const allOptions = {
        ...options,
        ...filterByPrimaryLabelProp,
    };
    const elementsQueryResult = yield call(loadElements, context, {
        displayFormRef: enableDuplicatedLabelValuesInAttributeFilter && attributeFilterDisplayAsLabelRef
            ? attributeFilterDisplayAsLabelRef
            : attributeFilterDisplayFormRef,
        ...allOptions,
    }, {
        hiddenElements,
        attribute,
    }, staticElements, cacheId);
    return {
        elements: elementsQueryResult.items,
        totalCount: elementsQueryResult.totalCount,
        options: omit(allOptions, "signal"),
        cacheId: elementsQueryResult.cacheId,
    };
}
//# sourceMappingURL=elementsSaga.js.map