// (C) 2021-2025 GoodData Corporation
import { newNegativeAttributeFilter, newPositiveAttributeFilter, } from "@gooddata/sdk-model";
// in current version of @reduxjs/toolkit esm export are not defined
// we need direct import from esm module otherwise import ar not node compatible
// https://github.com/reduxjs/redux-toolkit/issues/1960
import { createSelector } from "@reduxjs/toolkit/dist/redux-toolkit.esm.js";
import difference from "lodash/difference.js";
import union from "lodash/union.js";
import uniq from "lodash/uniq.js";
import { selectState } from "../common/selectors.js";
import { selectCommittedSelection, selectIsCommittedSelectionInverted, } from "../selection/selectionSelectors.js";
import { selectElements } from "../elements/elementsSelectors.js";
/**
 * @internal
 */
export const selectAttributeFilterElementsForm = createSelector(selectState, (state) => state.elementsForm);
/**
 * @internal
 */
export const selectHiddenElements = createSelector(selectState, (state) => state.config.hiddenElements ?? []);
/**
 * @internal
 */
export const selectHiddenElementsAsAttributeElements = createSelector(selectAttributeFilterElementsForm, selectHiddenElements, (elementsForm, hiddenElements) => elementsForm === "uris" ? { uris: hiddenElements } : { values: hiddenElements });
/**
 * @internal
 */
export const selectAttributeFilterDisplayForm = createSelector(selectState, (state) => state.displayFormRef);
/**
 * @internal
 */
export const selectAttributeFilterDisplayAsLabel = createSelector(selectState, (state) => state.displayAsLabelRef);
/**
 * @internal
 */
export const selectAttributeFilterLocalIdentifier = createSelector(selectState, (state) => state.localIdentifier);
/**
 * @internal
 */
export const selectOriginalFilter = createSelector(selectState, (state) => state.originalFilter);
/**
 * @internal
 */
export const selectAttributeFilterElements = createSelector(selectAttributeFilterElementsForm, selectCommittedSelection, (elementsForm, selection) => elementsForm === "uris" ? { uris: selection } : { values: selection });
/**
 * @internal
 */
export const selectAttributeFilterElementsWithHiddenElementsResolved = createSelector(selectAttributeFilterElementsForm, selectCommittedSelection, selectIsCommittedSelectionInverted, selectHiddenElements, (elementsForm, selection, isInverted, hiddenElements) => {
    const updatedSelection = isInverted
        ? union(selection, hiddenElements)
        : difference(selection, hiddenElements);
    return elementsForm === "uris"
        ? { uris: updatedSelection }
        : { values: updatedSelection };
});
/**
 * Return filter in form given by displayAsLabel
 * @internal
 */
export const selectAttributeFilterElementsToDisplayWithHiddenElementsResolved = createSelector(selectAttributeFilterElementsForm, selectCommittedSelection, selectIsCommittedSelectionInverted, selectHiddenElements, selectElements, (elementsForm, selection, isInverted, hiddenElements, elements) => {
    const updatedSelection = isInverted
        ? union(selection, hiddenElements)
        : difference(selection, hiddenElements);
    const selectedTitles = elements
        .filter((element) => updatedSelection.find((selectionItem) => selectionItem === element.uri))
        .map((element) => element.title);
    const uniqueTitles = uniq(selectedTitles);
    return elementsForm === "uris"
        ? { uris: uniqueTitles }
        : { values: uniqueTitles };
});
/**
 * @internal
 */
export const selectAttributeFilter = createSelector(selectAttributeFilterDisplayForm, selectIsCommittedSelectionInverted, selectAttributeFilterElementsWithHiddenElementsResolved, selectAttributeFilterLocalIdentifier, (displayForm, isInverted, elements, localIdentifier) => isInverted
    ? newNegativeAttributeFilter(displayForm, elements, localIdentifier)
    : newPositiveAttributeFilter(displayForm, elements, localIdentifier));
/**
 * @internal
 */
export const selectAttributeFilterToDisplay = createSelector(selectAttributeFilterDisplayForm, selectAttributeFilterDisplayAsLabel, selectIsCommittedSelectionInverted, selectAttributeFilterElementsWithHiddenElementsResolved, selectAttributeFilterElementsToDisplayWithHiddenElementsResolved, selectAttributeFilterLocalIdentifier, (displayForm, displayAsLabel, isInverted, primaryElements, secondaryElements, localIdentifier) => isInverted
    ? newNegativeAttributeFilter(displayAsLabel ?? displayForm, displayAsLabel ? secondaryElements : primaryElements, localIdentifier)
    : newPositiveAttributeFilter(displayAsLabel ?? displayForm, displayAsLabel ? secondaryElements : primaryElements, localIdentifier));
//# sourceMappingURL=filterSelectors.js.map