import { select, fork, take, race, call } from "redux-saga/effects";
import { isAttributeElementsByRef } from "@gooddata/sdk-model";
import { loadCustomElementsSaga } from "../loadCustomElements/loadCustomElementsSaga.js";
import { selectAttributeFilterElements } from "../filter/filterSelectors.js";
import { actions } from "../store/slice.js";
import { getAttributeFilterContext } from "../common/sagas.js";
import { selectElementsForm } from "../common/selectors.js";
import { shouldExcludePrimaryLabel } from "../utils.js";
import { INIT_SELECTION_PREFIX } from "../constants.js";
/**
 * @internal
 */
export function* initSelectionSaga(correlation) {
    const elements = yield select(selectAttributeFilterElements);
    const context = yield call(getAttributeFilterContext);
    const elementsForm = yield select(selectElementsForm);
    const elementKeys = isAttributeElementsByRef(elements) ? elements.uris : elements.values;
    if (elementKeys.length === 0) {
        return;
    }
    const initSelectionCorrelation = `${INIT_SELECTION_PREFIX}${correlation}`;
    yield fork(loadCustomElementsSaga, actions.loadCustomElementsRequest({
        options: {
            elements,
            offset: 0,
            limit: Math.max(550, elementKeys.length),
            search: undefined,
            excludePrimaryLabel: shouldExcludePrimaryLabel(context, elementsForm),
        },
        correlation: initSelectionCorrelation,
    }));
    const { error, } = yield race({
        success: take((a) => actions.loadCustomElementsSuccess.match(a) &&
            a.payload.correlation === initSelectionCorrelation),
        error: take((a) => actions.loadCustomElementsError.match(a) &&
            a.payload.correlation === initSelectionCorrelation),
        cancel: take((a) => actions.loadCustomElementsCancel.match(a) &&
            a.payload.correlation === initSelectionCorrelation),
    });
    if (error) {
        throw error.payload.error;
    }
}
//# sourceMappingURL=initSelectionSaga.js.map