import identity from "lodash/identity.js";
import { getElementCacheKey } from "../common/selectors.js";
import { isElementsQueryOptionsElementsByPrimaryDisplayFormValue, isElementsQueryOptionsElementsByValue, } from "@gooddata/sdk-backend-spi";
import { INIT_SELECTION_PREFIX } from "../constants.js";
const loadCustomElementsRequest = identity;
const loadCustomElementsStart = identity;
const getElementValues = (elements) => {
    if (!elements) {
        return [];
    }
    if (isElementsQueryOptionsElementsByValue(elements)) {
        return elements.values;
    }
    if (isElementsQueryOptionsElementsByPrimaryDisplayFormValue(elements)) {
        return elements.primaryValues;
    }
    return elements.uris;
};
const loadCustomElementsSuccess = (state, action) => {
    const keys = [];
    const { enableDuplicatedLabelValuesInAttributeFilter, options: { elements, filterByPrimaryLabel }, correlation, } = action.payload;
    const shouldOverrideKeys = state.initialization.status === "loading" && correlation.startsWith(INIT_SELECTION_PREFIX);
    if (enableDuplicatedLabelValuesInAttributeFilter && elements) {
        const originalElements = getElementValues(elements);
        // iterate over original elements to keep the order in selection,
        // fetched elements are sorted by default
        originalElements.forEach((originalEl) => {
            action.payload.elements
                .filter((el) => (filterByPrimaryLabel ? el.uri === originalEl : el.title === originalEl))
                .forEach((el) => {
                const cacheKey = getElementCacheKey(state, el, enableDuplicatedLabelValuesInAttributeFilter);
                if (!state.elements.cache[cacheKey]) {
                    state.elements.cache[cacheKey] = el;
                }
                if (shouldOverrideKeys) {
                    keys.push(cacheKey);
                }
            });
        });
    }
    else {
        action.payload.elements.forEach((el) => {
            const cacheKey = getElementCacheKey(state, el, enableDuplicatedLabelValuesInAttributeFilter);
            if (!state.elements.cache[cacheKey]) {
                state.elements.cache[cacheKey] = el;
            }
            if (shouldOverrideKeys) {
                keys.push(cacheKey);
            }
        });
    }
    if (enableDuplicatedLabelValuesInAttributeFilter && shouldOverrideKeys) {
        state.selection.working.keys = keys;
        state.selection.commited.keys = keys;
    }
};
const loadCustomElementsError = identity;
const loadCustomElementsCancelRequest = identity;
const loadCustomElementsCancel = identity;
/**
 * @internal
 */
export const loadCustomElementsReducers = {
    loadCustomElementsRequest,
    loadCustomElementsStart,
    loadCustomElementsSuccess,
    loadCustomElementsError,
    loadCustomElementsCancelRequest,
    loadCustomElementsCancel,
};
//# sourceMappingURL=loadCustomElementsReducers.js.map