// (C) 2022-2024 GoodData Corporation
import { filterObjRef, newNegativeAttributeFilter, newPositiveAttributeFilter, filterAttributeElements, isAttributeElementsByRef, isPositiveAttributeFilter, filterLocalIdentifier, } from "@gooddata/sdk-model";
import { AttributeFilterLoader } from "./loader.js";
/**
 * @internal
 */
export class SingleSelectAttributeFilterHandler extends AttributeFilterLoader {
    static sanitizeConfig(config) {
        const elements = filterAttributeElements(config.attributeFilter);
        const keys = isAttributeElementsByRef(elements) ? elements.uris : elements.values;
        const firstItem = keys[0];
        const sanitizedItems = isAttributeElementsByRef(elements)
            ? { uris: [firstItem] }
            : { values: [firstItem] };
        return {
            ...config,
            attributeFilter: isPositiveAttributeFilter(config.attributeFilter)
                ? newPositiveAttributeFilter(filterObjRef(config.attributeFilter), sanitizedItems, filterLocalIdentifier(config.attributeFilter))
                : newNegativeAttributeFilter(filterObjRef(config.attributeFilter), sanitizedItems, filterLocalIdentifier(config.attributeFilter)),
        };
    }
    constructor(config) {
        super(SingleSelectAttributeFilterHandler.sanitizeConfig(config));
    }
    // manipulators
    changeSelection = (selection) => {
        this.bridge.changeSingleSelection(selection);
    };
    revertSelection = () => {
        this.bridge.revertSingleSelection();
    };
    commitSelection = () => {
        this.bridge.commitSingleSelection();
    };
    // selectors
    getWorkingSelection = () => {
        return this.bridge.getWorkingSingleSelection();
    };
    isWorkingSelectionEmpty = () => {
        return this.bridge.getIsWorkingSelectionEmpty();
    };
    isWorkingSelectionChanged = () => {
        return this.bridge.getIsWorkingSelectionChanged();
    };
    getCommittedSelection = () => {
        return this.bridge.getCommittedSingleSelection();
    };
    // callbacks
    onSelectionChanged = (cb) => {
        return this.bridge.onSingleSelectionChanged(cb);
    };
    onSelectionCommitted = (cb) => {
        return this.bridge.onSingleSelectionCommitted(cb);
    };
}
//# sourceMappingURL=singleSelectHandler.js.map