// (C) 2025 GoodData Corporation
import React, { forwardRef, useState } from "react";
import { Overlay } from "@gooddata/sdk-ui-kit";
import { DayPicker as DayPickerComponent, } from "react-day-picker";
import enUS from "date-fns/locale/en-US/index.js";
import de from "date-fns/locale/de/index.js";
import es from "date-fns/locale/es/index.js";
import fr from "date-fns/locale/fr/index.js";
import ja from "date-fns/locale/ja/index.js";
import nl from "date-fns/locale/nl/index.js";
import pt from "date-fns/locale/pt/index.js";
import ptBR from "date-fns/locale/pt-BR/index.js";
import zhCN from "date-fns/locale/zh-CN/index.js";
import ru from "date-fns/locale/ru/index.js";
import it from "date-fns/locale/it/index.js";
import enGB from "date-fns/locale/en-GB/index.js";
import frCA from "date-fns/locale/fr-CA/index.js";
import enAU from "date-fns/locale/en-AU/index.js";
import fi from "date-fns/locale/fi/index.js";
import tr from "date-fns/locale/tr/index.js";
import pl from "date-fns/locale/pl/index.js";
import ko from "date-fns/locale/ko/index.js";
import { mergeDayPickerProps } from "./utils.js";
const convertedLocales = {
    "en-US": enUS,
    "de-DE": de,
    "es-ES": es,
    "fr-FR": fr,
    "ja-JP": ja,
    "nl-NL": nl,
    "pt-BR": ptBR,
    "pt-PT": pt,
    "zh-Hans": zhCN,
    "ru-RU": ru,
    "it-IT": it,
    "es-419": es,
    "en-GB": enGB,
    "fr-CA": frCA,
    "zh-Hant": zhCN,
    "en-AU": enAU,
    "fi-FI": fi,
    "zh-HK": zhCN,
    "tr-TR": tr,
    "pl-PL": pl,
    "ko-KR": ko,
};
const ALIGN_POINTS = [{ align: "bl tl", offset: { x: 0, y: 1 } }];
const convertLocale = (locale) => convertedLocales[locale];
function convertWeekStart(weekStart) {
    switch (weekStart) {
        case "Sunday":
            return 0;
        case "Monday":
            return 1;
        default:
            throw new Error(`Unknown week start ${weekStart}`);
    }
}
export const DayPicker = forwardRef(({ mode, originalDateRange, selectedDateRange, onDateRangeSelect, dayPickerProps, alignTo, weekStart, renderAsOverlay, calendarClassNames, intl, }, ref) => {
    const [currentMonthDate, setCurrentMonthDate] = useState(mode === "from" ? selectedDateRange.from : selectedDateRange.to);
    const defaultDayPickerProps = {
        mode: "range",
        showOutsideDays: true,
        modifiers: { start: originalDateRange.from, end: originalDateRange.to },
        selected: { from: originalDateRange.from, to: originalDateRange.to },
        locale: convertLocale(intl.locale),
    };
    const dayPickerPropsWithDefaults = mergeDayPickerProps(defaultDayPickerProps, dayPickerProps);
    const DatePicker = (React.createElement("div", { className: "gd-date-range-picker-wrapper", ref: ref },
        React.createElement(DayPickerComponent, { ...dayPickerPropsWithDefaults, month: currentMonthDate, onSelect: onDateRangeSelect, selected: selectedDateRange, classNames: {
                root: calendarClassNames,
            }, onMonthChange: setCurrentMonthDate, weekStartsOn: convertWeekStart(weekStart) })));
    const OverlayDatePicker = (React.createElement(Overlay, { alignTo: alignTo, alignPoints: ALIGN_POINTS, closeOnOutsideClick: true, closeOnMouseDrag: true, closeOnParentScroll: true }, DatePicker));
    if (renderAsOverlay) {
        return OverlayDatePicker;
    }
    return DatePicker;
});
DayPicker.displayName = "DayPicker";
//# sourceMappingURL=DatePicker.js.map