// (C) 2022-2025 GoodData Corporation
import React, { useMemo } from "react";
import cx from "classnames";
import { injectIntl } from "react-intl";
import { TimeInput } from "./TimeInput.js";
import { DateInput } from "./DateInput.js";
const DateTimePickerComponent = React.forwardRef(({ date, time, dateInputLabel, timeInputLabel, onDateChange, onTimeChange, onDayClick, onDateInputKeyDown, dateFormat, isMobile, isTimeEnabled, className, accessibilityConfig, inputErrorMessageTexts, errors, }, ref) => {
    const { dateAriaLabel, timeAriaLabel, dateInputHintId, timeInputHintId } = accessibilityConfig;
    const dateInputAccessibilityConfig = useMemo(() => ({
        ariaLabel: dateAriaLabel,
        inputHintId: dateInputHintId,
    }), [dateAriaLabel, dateInputHintId]);
    const timeInputAccessibilityConfig = useMemo(() => ({
        ariaLabel: timeAriaLabel,
        inputHintId: timeInputHintId,
    }), [timeAriaLabel, timeInputHintId]);
    const timeInputErrorText = errors?.isTimeOrderError
        ? inputErrorMessageTexts.timeInput.startTimeAfterEndTime
        : undefined;
    return (React.createElement("div", { className: cx(className, { "gd-date-range-row": isTimeEnabled }) },
        React.createElement("fieldset", null,
            React.createElement(DateInput, { ref: ref, value: date, inputLabel: dateInputLabel, onChange: onDateChange, onKeyDown: onDateInputKeyDown, onClick: onDayClick, dateFormat: dateFormat, accessibilityConfig: dateInputAccessibilityConfig, errorMessageTexts: inputErrorMessageTexts.dateInput, isDateOrderError: errors?.isDateOrderError, isMobile: isMobile, isTimeEnabled: isTimeEnabled }),
            isTimeEnabled ? (React.createElement(TimeInput, { value: time, inputLabel: timeInputLabel, onChange: onTimeChange, accessibilityConfig: timeInputAccessibilityConfig, errorText: timeInputErrorText, isMobile: isMobile })) : null)));
});
DateTimePickerComponent.displayName = "DateTimePickerComponent";
export const DateTimePicker = injectIntl(DateTimePickerComponent, { forwardRef: true });
DateTimePicker.displayName = "DateTimePicker";
//# sourceMappingURL=DateTimePicker.js.map