// (C) 2025 GoodData Corporation
import React, { forwardRef, useMemo } from "react";
import cx from "classnames";
import { DAY_START_TIME } from "../constants/Platform.js";
import { getLocalizedDateFormat } from "../utils/FormattingUtils.js";
import { DateTimePicker } from "./DateTimePicker.js";
import { DATE_INPUT_HINT_ID, TIME_INPUT_HINT_ID, } from "./types.js";
export const StartDateInputField = forwardRef(({ date, time, onDateInputKeyDown, onDateChange, onTimeChange, onInputClick, dateFormat, isMobile, isTimeEnabled, errors, intl, }, ref) => {
    const accessibilityConfig = useMemo(() => ({
        dateAriaLabel: intl.formatMessage({ id: "filters.date.accessibility.label.from" }),
        timeAriaLabel: intl.formatMessage({ id: "filters.time.accessibility.label.from" }),
        dateInputHintId: DATE_INPUT_HINT_ID,
        timeInputHintId: TIME_INPUT_HINT_ID,
    }), [intl]);
    const inputErrorMessageTexts = useMemo(() => ({
        dateInput: {
            emptyDate: intl.formatMessage({ id: "filters.staticPeriod.errors.emptyStartDate" }),
            invalidDate: intl.formatMessage({ id: "filters.staticPeriod.errors.invalidStartDate" }, { format: dateFormat || getLocalizedDateFormat(intl.locale) }),
            startDateAfterEndDate: intl.formatMessage({
                id: "filters.staticPeriod.errors.startDateAfterEndDate",
            }),
        },
        timeInput: {
            startTimeAfterEndTime: intl.formatMessage({
                id: "filters.staticPeriod.errors.startTimeAfterEndTime",
            }),
        },
    }), [intl, dateFormat]);
    return (React.createElement(DateTimePicker, { ref: ref, date: date, time: time, onDateChange: onDateChange, onTimeChange: onTimeChange, onDateInputKeyDown: onDateInputKeyDown, dateInputLabel: intl.formatMessage({ id: "filters.staticPeriod.dateFrom" }), timeInputLabel: intl.formatMessage({ id: "filters.staticPeriod.timeFrom" }), accessibilityConfig: accessibilityConfig, dateFormat: dateFormat, isMobile: isMobile, onDayClick: onInputClick, isTimeEnabled: isTimeEnabled, className: cx("s-date-range-picker-from", "gd-date-range-picker-from"), defaultTime: DAY_START_TIME, inputErrorMessageTexts: inputErrorMessageTexts, errors: errors }));
});
StartDateInputField.displayName = "FromInputField";
//# sourceMappingURL=StartDateInputField.js.map