// (C) 2007-2023 GoodData Corporation
import React from "react";
import isNumber from "lodash/isNumber.js";
import defaultTo from "lodash/defaultTo.js";
import clamp from "lodash/clamp.js";
import { ArrowButton } from "./ArrowButton.js";
import { unless } from "./utils.js";
const isIntermediateValue = (value) => value === "" || value === "-";
const isNumericOrEmptyString = (value) => value === "" || isNumber(value);
const UP_ARROW_CODE = 38;
const DOWN_ARROW_CODE = 40;
export class NumericInput extends React.Component {
    render() {
        const { props, handleChange, handleKeyDown, increment, decrement, isIncrementDisabled, isDecrementDisabled, } = this;
        return (React.createElement("label", { className: "gd-input gd-input-with-suffix gd-numeric-input" },
            React.createElement("input", { type: "text", className: "gd-input-field", value: props.value, placeholder: props.placeholder, onChange: handleChange, onKeyDown: handleKeyDown }),
            React.createElement(ArrowButton, { arrowDirection: "increment", disabled: isIncrementDisabled(), onClick: increment }),
            React.createElement(ArrowButton, { arrowDirection: "decrement", disabled: isDecrementDisabled(), onClick: decrement })));
    }
    isIncrementDisabled = () => !isNumericOrEmptyString(this.props.value) ||
        (this.props.max !== undefined && isNumber(this.props.value) && this.props.value >= this.props.max);
    isDecrementDisabled = () => !isNumericOrEmptyString(this.props.value) ||
        (this.props.min !== undefined && isNumber(this.props.value) && this.props.value <= this.props.min);
    clampToRange = (value) => {
        const { max, min } = this.props;
        const upperBound = defaultTo(max, Infinity);
        const lowerBound = defaultTo(min, -Infinity);
        return clamp(value, lowerBound, upperBound);
    };
    handleChange = (e) => {
        if (isIntermediateValue(e.target.value)) {
            this.props.onChange(e.target.value);
        }
        const parsedValue = Number.parseInt(e.target.value, 10);
        if (Number.isInteger(parsedValue)) {
            this.props.onChange(parsedValue);
        }
    };
    valueChanger = (delta) => () => this.props.onChange(isIntermediateValue(this.props.value) ? delta : this.clampToRange(this.props.value + delta));
    increment = this.valueChanger(1);
    decrement = this.valueChanger(-1);
    keyDownHandlers = {
        [UP_ARROW_CODE]: () => unless(this.isIncrementDisabled, this.increment),
        [DOWN_ARROW_CODE]: () => unless(this.isDecrementDisabled, this.decrement),
    };
    handleKeyDown = (e) => {
        const handler = this.keyDownHandlers[e.keyCode];
        if (handler) {
            handler();
        }
    };
}
//# sourceMappingURL=NumericInput.js.map