// (C) 2025 GoodData Corporation
import React, { useCallback, useRef } from "react";
import cx from "classnames";
import { isRelativeDateFilterForm } from "@gooddata/sdk-model";
import { ListItem } from "../ListItem/ListItem.js";
import { FormattedMessage } from "react-intl";
import { ListItemTooltip } from "../ListItemTooltip/ListItemTooltip.js";
import { DateFilterFormWrapper } from "../DateFilterFormWrapper/DateFilterFormWrapper.js";
import { createDateFilterRelativeFormKeyboardHandler, submitRelativeDateFilterForm, } from "../accessibility/keyboardNavigation.js";
import { RelativeDateFilterForm } from "./RelativeDateFilterForm.js";
import { useId } from "@gooddata/sdk-ui-kit";
import isEmpty from "lodash/isEmpty.js";
const ITEM_CLASS_MOBILE = "gd-date-filter-item-mobile";
export const RelativeDateFilterFormSection = ({ filterOptions, selectedFilterOption, isMobile, route, availableGranularities, errors, onSelectedFilterOptionChange, changeRoute, closeDropdown, onApplyClick, }) => {
    const relativeDateFilterRef = useRef(null);
    const tabGranularityRef = useRef(null);
    const relativeDateFilterId = useId();
    const handleRelativeDateFilterKeydown = useCallback((event, closeDropdown) => {
        const keyboardHandler = createDateFilterRelativeFormKeyboardHandler({
            relativeDateFilterRef,
            tabGranularityRef,
            closeDropdown,
        });
        keyboardHandler(event);
    }, [relativeDateFilterRef, tabGranularityRef]);
    if (!filterOptions.relativeForm) {
        return null;
    }
    const isSelected = filterOptions.relativeForm.localIdentifier === selectedFilterOption.localIdentifier;
    const isOnRoute = route === "relativeForm";
    return (React.createElement(React.Fragment, null,
        !isMobile || !isOnRoute ? (React.createElement(ListItem, { isSelected: isSelected, onClick: () => {
                changeRoute("relativeForm");
                if (!isRelativeDateFilterForm(selectedFilterOption)) {
                    onSelectedFilterOptionChange(filterOptions.relativeForm);
                }
            }, className: cx("s-relative-form", "s-do-not-close-dropdown-on-click", isMobile && ITEM_CLASS_MOBILE) },
            filterOptions.relativeForm.name ? (filterOptions.relativeForm.name) : (React.createElement(FormattedMessage, { id: "filters.floatingRange" })),
            !isMobile ? (React.createElement(ListItemTooltip, { bubbleAlignPoints: [{ align: "cr cl" }] },
                React.createElement(FormattedMessage, { id: "filters.floatingRange.tooltip" }))) : null)) : null,
        isSelected && (!isMobile || isOnRoute) ? (React.createElement(DateFilterFormWrapper, { isMobile: isMobile },
            React.createElement("div", { ref: relativeDateFilterRef, onKeyDown: (e) => handleRelativeDateFilterKeydown(e, closeDropdown) },
                React.createElement(RelativeDateFilterForm, { onSelectedFilterOptionChange: onSelectedFilterOptionChange, selectedFilterOption: selectedFilterOption, availableGranularities: availableGranularities, isMobile: isMobile, ref: tabGranularityRef, relativeDateFilterId: relativeDateFilterId, onKeyDown: (event) => submitRelativeDateFilterForm(event, isEmpty(errors), closeDropdown, onApplyClick) })))) : null));
};
//# sourceMappingURL=RelativeDateFilterFormSection.js.map