// (C) 2007-2022 GoodData Corporation
import React from "react";
import cx from "classnames";
import { SelectOption } from "./SelectOption.js";
import { SelectHeading } from "./SelectHeading.js";
import { SelectSeparator } from "./SelectSeparator.js";
import { getSelectableItems } from "./utils.js";
// eslint-disable-next-line @typescript-eslint/ban-types
export const SelectMenu = ({ items, selectedItem, highlightedIndex, getItemProps, getMenuProps, className, optionClassName, }) => {
    const selectableOptions = getSelectableItems(items);
    return (React.createElement("div", { ...getMenuProps({ className: cx("gd-select-menu-wrapper", className) }) },
        React.createElement("div", { className: "gd-select-menu s-select-menu" }, items.map((item, index) => {
            if (item.type === "option") {
                const isSelected = selectedItem && item ? selectedItem.value === item.value : false;
                const isFocused = selectableOptions[highlightedIndex] && item
                    ? selectableOptions[highlightedIndex].value === item.value
                    : false;
                return (
                // The key is handled by the getItemProps from downshift
                // eslint-disable-next-line react/jsx-key
                React.createElement(SelectOption, { ...getItemProps({
                        key: `${item.type}-${item.value}`,
                        item,
                        index: selectableOptions.indexOf(item),
                        isSelected,
                        className: optionClassName,
                    }), isFocused: isFocused }, item.label));
            }
            else if (item.type === "heading") {
                return React.createElement(SelectHeading, { key: `${item.type}-${item.label}` }, item.label);
            }
            else if (item.type === "separator") {
                return React.createElement(SelectSeparator, { key: `${item.type}-${index}` });
            }
            return null;
        }))));
};
//# sourceMappingURL=SelectMenu.js.map