import React from "react";
/**
 * Configuration for Date filter keyboard navigation handler
 * @internal
 */
interface IDateFilterKeyboardNavigationConfig {
    /** Reference to the date filter container element */
    dateFilterContainerRef: React.MutableRefObject<HTMLDivElement>;
    /** Reference to the date filter body element */
    dateFilterBodyRef: React.MutableRefObject<HTMLDivElement>;
    /** Optional callback to close the dropdown */
    closeDropdown?: () => void;
}
/**
 * Configuration for Date filter - Relative form keyboard navigation handler
 * @internal
 */
interface IDateFilterRelativeFormKeyboardNavigationConfig {
    /** Reference to the relative filter body element */
    relativeDateFilterRef: React.MutableRefObject<HTMLDivElement>;
    /** Reference to the relative filter granularity tabs element */
    tabGranularityRef: React.MutableRefObject<HTMLDivElement>;
    /** Callback to close the dropdown */
    closeDropdown?: () => void;
}
/**
 * Creates a keyboard event handler for the date filter component
 * @param config - Configuration object containing ref and optional close handler
 * @returns Keyboard event handler function
 * @internal
 */
export declare const createDateFilterKeyboardHandler: ({ dateFilterContainerRef, dateFilterBodyRef, closeDropdown }: IDateFilterKeyboardNavigationConfig) => (event: React.KeyboardEvent) => void;
/**
 * Creates a keyboard event handler for the date filter component
 * @param config - Configuration object containing ref and optional close handler
 * @returns Keyboard event handler function
 * @internal
 */
export declare const createDateFilterRelativeFormKeyboardHandler: ({ tabGranularityRef, closeDropdown, }: IDateFilterRelativeFormKeyboardNavigationConfig) => (event: React.KeyboardEvent) => void;
export declare const submitRelativeDateFilterForm: (event: React.KeyboardEvent, canSubmit: boolean, onSubmit: () => void, submit: () => void) => void;
export {};
//# sourceMappingURL=keyboardNavigation.d.ts.map