// (C) 2007-2025 GoodData Corporation
import React from "react";
import { injectIntl } from "react-intl";
import cx from "classnames";
import capitalize from "lodash/capitalize.js";
import { Button } from "@gooddata/sdk-ui-kit";
import { stringUtils } from "@gooddata/util";
import OperatorDropdownBody from "./OperatorDropdownBody.js";
import { getOperatorTranslationKey, getOperatorIcon } from "./helpers/measureValueFilterOperator.js";
export class OperatorDropdown extends React.PureComponent {
    state = {
        opened: false,
    };
    render() {
        return (React.createElement(React.Fragment, null,
            this.renderDropdownButton(),
            this.state.opened ? (React.createElement(OperatorDropdownBody, { alignTo: ".gd-mvf-operator-dropdown-button", onSelect: this.handleOperatorSelected, selectedOperator: this.props.operator, onClose: this.closeOperatorDropdown })) : null));
    }
    renderDropdownButton() {
        const { intl, operator, isDisabled } = this.props;
        const { opened } = this.state;
        const operatorTranslationKey = getOperatorTranslationKey(operator);
        const title = capitalize(operatorTranslationKey === undefined
            ? operator
            : intl.formatMessage({ id: operatorTranslationKey }));
        const buttonClasses = cx("gd-mvf-operator-dropdown-button", "s-mvf-operator-dropdown-button", `s-mvf-operator-dropdown-button-${stringUtils.simplifyText(operator)}`, "gd-button-primary", "gd-button-small", {
            "button-dropdown": true,
            "is-dropdown-open": opened,
            "is-active": opened,
        });
        return (React.createElement(Button, { title: title, className: buttonClasses, value: title, onClick: this.handleOperatorDropdownButtonClick, iconLeft: `gd-icon-${getOperatorIcon(operator)}`, iconRight: opened ? "gd-icon-navigateup" : "gd-icon-navigatedown", disabled: isDisabled }));
    }
    handleOperatorSelected = (operator) => {
        this.closeOperatorDropdown();
        this.props.onSelect(operator);
    };
    closeOperatorDropdown = () => this.setState({ opened: false });
    handleOperatorDropdownButtonClick = () => this.setState((state) => ({ ...state, opened: !state.opened }));
}
export default injectIntl(OperatorDropdown);
//# sourceMappingURL=OperatorDropdown.js.map